<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AnnsActionDialog</name>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="14"/>
        <source>New Annotations Action</source>
        <translation>Новые аннотации</translation>
    </message>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="34"/>
        <source>Merge into one annotation table</source>
        <translation>Соединить в одну таблицу</translation>
    </message>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="53"/>
        <source>Shift annotations using
this merge sequence slot:</source>
        <translation>Сдвинуть аннотации
используя слот:</translation>
    </message>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="64"/>
        <source>Filter duplicated annotations</source>
        <translation>Отфильтровать повторы</translation>
    </message>
</context>
<context>
    <name>BreakpointHitCountDialog</name>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="26"/>
        <source>Breakpoint Hit Count</source>
        <translation>Счетчик точек остановки</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="50"/>
        <source>When the breakpoint is h&amp;it:</source>
        <translation>Условие о&amp;становки:</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="89"/>
        <source>Current hit count:</source>
        <translation>Текущее значение:</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="96"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="43"/>
        <source>A breakpoint is hit when the breakpoint location is reached and the condition is&lt;br&gt;satisfied. The hit count is the number of times the breakpoint has been hit.</source>
        <translation>Остановка произойдет когда текущее состояние достигнет критической точки и условия &lt;br&gt;будут выполнены. Количество совпадений - это сколько раз сработала точка остановки.</translation>
    </message>
</context>
<context>
    <name>CreateDirectoryDialog</name>
    <message>
        <location filename="../src/CreateDirectoryDialog.ui" line="14"/>
        <source>Create a directory</source>
        <translation>Создать директорию</translation>
    </message>
    <message>
        <location filename="../src/CreateDirectoryDialog.ui" line="43"/>
        <source>Parent directory:</source>
        <translation>Родительская директория:</translation>
    </message>
    <message>
        <location filename="../src/CreateDirectoryDialog.ui" line="63"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
</context>
<context>
    <name>DatasetWidget</name>
    <message>
        <location filename="../src/DatasetWidget.ui" line="20"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="40"/>
        <source>Add file(s)</source>
        <translation>Добавить файл(ы)</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="62"/>
        <source>Add directory</source>
        <translation>Добавить директорию</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="94"/>
        <source>Up url(s)</source>
        <translation>Переместить путь(и) выше</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="119"/>
        <source>Down url(s)</source>
        <translation>Переместить путь(и) ниже</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="144"/>
        <source>Delete urls(s)</source>
        <translation>Удалить путь(и)</translation>
    </message>
</context>
<context>
    <name>DbFolderOptions</name>
    <message>
        <location filename="../src/DbFolderOptions.ui" line="32"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/DbFolderOptions.ui" line="50"/>
        <source>Recursive</source>
        <translation>Рекурсивно</translation>
    </message>
</context>
<context>
    <name>DirectoryOptions</name>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="32"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="46"/>
        <source>Exclude mask</source>
        <translation>Исключить маску</translation>
    </message>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="75"/>
        <source>Inсlude mask</source>
        <translation>Включить маску</translation>
    </message>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="112"/>
        <source>Recursive</source>
        <translation>Рекурсивно</translation>
    </message>
</context>
<context>
    <name>EditBreakpointLabelsDialog</name>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="60"/>
        <source>O&amp;r choose among existing labels</source>
        <translation>И&amp;ли выберите среди существующих ярлыков</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="53"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="26"/>
        <source>Edit Breakpoint Labels</source>
        <translation>Редактирование ярлыков точек остановки</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="34"/>
        <source>T&amp;ype a new label</source>
        <translation>Т&amp;ип нового ярлыка</translation>
    </message>
</context>
<context>
    <name>EditFloatMarkerWidget</name>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="20"/>
        <source>Interval:</source>
        <translation>Интервал:</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="42"/>
        <source>..</source>
        <translation>..</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="64"/>
        <source>Less than:</source>
        <translation>Меньше чем:</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="94"/>
        <source>Greater than:</source>
        <translation>Больше чем:</translation>
    </message>
</context>
<context>
    <name>EditIntegerMarkerWidget</name>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="20"/>
        <source>Interval:</source>
        <translation>Интервал:</translation>
    </message>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="42"/>
        <source>..</source>
        <translation>..</translation>
    </message>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="61"/>
        <source>Less than:</source>
        <translation>Меньше чем:</translation>
    </message>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="88"/>
        <source>Greater than:</source>
        <translation>Больше чем:</translation>
    </message>
</context>
<context>
    <name>EditMarkerDialog</name>
    <message>
        <location filename="../src/EditMarkerDialog.ui" line="14"/>
        <source>Edit Marker</source>
        <translation>Свойства маркера</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerDialog.ui" line="28"/>
        <source>Marker name:</source>
        <translation>Имя маркера:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerDialog.ui" line="35"/>
        <source>NewMarker</source>
        <translation>Новый маркер</translation>
    </message>
</context>
<context>
    <name>EditMarkerGroupDialog</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="14"/>
        <source>Edit Marker Group</source>
        <translation>Свойства группы маркеров</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="22"/>
        <source>Marker group name:</source>
        <translation>Имя группы маркеров:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="29"/>
        <source>NewMarkerGroup</source>
        <translation>Новая группа маркеров</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="36"/>
        <source>Marker group type:</source>
        <translation>Тип группы маркеров:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="46"/>
        <source>Parameter:</source>
        <translation>Параметр:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="60"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="80"/>
        <source>Edit</source>
        <translation>Редактивароть</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="87"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>EditStringMarkerWidget</name>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="20"/>
        <source>Starts with</source>
        <translation>Начиная с</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="33"/>
        <source>Ends with</source>
        <translation>Заканчивая</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="43"/>
        <source>Contains</source>
        <translation>Содержит</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="53"/>
        <source>Regular expression</source>
        <translation>Регулярное выражение</translation>
    </message>
</context>
<context>
    <name>GrouperEditorWidget</name>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="22"/>
        <source>Group slot</source>
        <translation>Слот</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="39"/>
        <source>Group operation</source>
        <translation>Операция</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="60"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="80"/>
        <source>Edit</source>
        <translation>Редактивароть</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="87"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>MarkerEditorWidget</name>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="22"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="42"/>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="49"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>MsaActionDialog</name>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="26"/>
        <source>New Alignment Action</source>
        <translation>Новое выравнивание</translation>
    </message>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="34"/>
        <source>Merge into one alignment</source>
        <translation>Соединить в одно выравнивание</translation>
    </message>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="50"/>
        <source>Alignment name</source>
        <translation>Имя выравнивания</translation>
    </message>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="60"/>
        <source>Filter duplicated rows</source>
        <translation>Отфильтровать повторяющиеся строки</translation>
    </message>
</context>
<context>
    <name>NewBreakpointDialog</name>
    <message>
        <location filename="../src/NewBreakpointDialog.ui" line="20"/>
        <source>New Breakpoint</source>
        <translation>Новая точка остановки</translation>
    </message>
    <message>
        <location filename="../src/NewBreakpointDialog.ui" line="28"/>
        <source>Break execution when it reaches this element in the workflow</source>
        <translation>Выполнение остановится, когда выполнение схемы дойдет до данного элемента</translation>
    </message>
    <message>
        <location filename="../src/NewBreakpointDialog.ui" line="35"/>
        <source>&amp;Element: </source>
        <translation>&amp;Элемент: </translation>
    </message>
</context>
<context>
    <name>NewGrouperSlotDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.ui" line="32"/>
        <source>Setup New Data Merge Action</source>
        <translation>Объединение данных</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.ui" line="43"/>
        <source>Source data slot</source>
        <translation>Слот с данными</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.ui" line="60"/>
        <source>Name of new slot with merged data</source>
        <translation>Имя нового слота с объединенными данными</translation>
    </message>
</context>
<context>
    <name>OutputFileDialog</name>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="14"/>
        <source>Save file/directory</source>
        <translation>Сохранить файл/директорию</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="31"/>
        <source>Create directory</source>
        <translation>Создать директорию</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="63"/>
        <location filename="../src/OutputFileDialog.ui" line="82"/>
        <source>Save to file system</source>
        <translation>Сохранить в файловую систему</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="126"/>
        <source>Directory:</source>
        <translation>Директория:</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="146"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/WorkflowGUIUtils.cpp" line="48"/>
        <source>Select a sample to start</source>
        <translation>Выберите пример</translation>
    </message>
    <message>
        <location filename="../src/WorkflowGUIUtils.cpp" line="155"/>
        <source>Double click to load the sample</source>
        <translation>Двойной щелчок загрузит пример</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="451"/>
        <source>Paired reads</source>
        <translation>Парные риды</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="453"/>
        <source>file</source>
        <translation>файл</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="453"/>
        <source>folder</source>
        <translation>папка</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="454"/>
        <source>UGENE has found &quot;%1&quot; on the file system. Do you want to add it as a second %2 with paired reads?</source>
        <translation>UGENE обнаружил &quot;%1&quot; в файловой системе. Хотите дабавить в качестве %2 с парными ридами?</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="36"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="51"/>
        <source>Workflow Estimation</source>
        <translation>Оценка выполнения схемы</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="52"/>
        <source>Approximate estimation time of the workflow run is </source>
        <translation>Примерная оценка длительности выполнения схемы </translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="168"/>
        <location filename="../src/OutputFileDialog.cpp" line="214"/>
        <source>Workflow-run output</source>
        <translation>Выходная папка схемы</translation>
    </message>
    <message>
        <location filename="../src/wizard/SelectorActors.cpp" line="42"/>
        <location filename="../src/wizard/WizardController.cpp" line="436"/>
        <source>Unknown actor id: %1</source>
        <translation>Неизвестный идентификатор: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="384"/>
        <location filename="../src/wizard/WizardController.cpp" line="391"/>
        <location filename="../src/wizard/WizardController.cpp" line="397"/>
        <location filename="../src/wizard/WizardController.cpp" line="415"/>
        <location filename="../src/wizard/WizardController.cpp" line="470"/>
        <source>Undefined variable: %1</source>
        <translation>Неопределенная переменная: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="423"/>
        <source>Actors selector is already defined: %1</source>
        <translation>Селектор уже определен: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="433"/>
        <source>Unknown actors selector: %1</source>
        <translation>Неизвестный селектор: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="438"/>
        <source>Unknown actors selector value id: %1</source>
        <translation>Неизвестный идентификатор значения селектора: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardPageController.cpp" line="83"/>
        <source>The page is broken. Please, close the wizard and report us the error: ugene@unipro.ru</source>
        <translation>Произошла ошибка. Пожалуйста закройте визард и сообщите об ошибке по адресу: ugene@unipro.ru</translation>
    </message>
</context>
<context>
    <name>SequeceActionDialog</name>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="32"/>
        <source>New Sequence Action</source>
        <translation>Новая последовательность</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="40"/>
        <source>Merge into one sequence</source>
        <translation>Соединить в одну последовательность</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="59"/>
        <source>Merged sequence name</source>
        <translation>Имя общей последовательности</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="69"/>
        <source>Gap size</source>
        <translation>Размер пробела</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="96"/>
        <source>Merge into alignment</source>
        <translation>Соединить в выравнивание</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="112"/>
        <source>Alignment name</source>
        <translation>Имя выравнивания</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="122"/>
        <source>Filter duplicated sequences</source>
        <translation>Отфильтровать повторяющиеся последовательности</translation>
    </message>
</context>
<context>
    <name>StringActionDialog</name>
    <message>
        <location filename="../src/StringActionDialog.ui" line="26"/>
        <source>New String Action</source>
        <translation>Новая строка</translation>
    </message>
    <message>
        <location filename="../src/StringActionDialog.ui" line="37"/>
        <source>Merge strings into one string</source>
        <translation>Соединить в одну строку</translation>
    </message>
    <message>
        <location filename="../src/StringActionDialog.ui" line="53"/>
        <source>Separator</source>
        <translation>Разделитель</translation>
    </message>
</context>
<context>
    <name>U2::AnnsActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="106"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="107"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="109"/>
        <source>Don&apos;t shift</source>
        <translation>Не сдвигать</translation>
    </message>
</context>
<context>
    <name>U2::BadgeLabel</name>
    <message>
        <location filename="../src/dashboard/ExternalToolsDashboardWidget.cpp" line="483"/>
        <source>Copy command line</source>
        <translation>Скопировать командную строку</translation>
    </message>
</context>
<context>
    <name>U2::BowtieWidgetController</name>
    <message>
        <location filename="../src/wizard/BowtieWidgetController.cpp" line="68"/>
        <source>Select
bowtie index file</source>
        <translation>Выберите
индексный bowtie файл</translation>
    </message>
    <message>
        <location filename="../src/wizard/BowtieWidgetController.cpp" line="79"/>
        <source>Select one of Bowtie index files</source>
        <translation>Выберите один индексный Bowtie файл</translation>
    </message>
</context>
<context>
    <name>U2::BreakpointHitCountDialog</name>
    <message>
        <location filename="../src/BreakpointHitCountDialog.cpp" line="73"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.cpp" line="74"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.cpp" line="75"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::ComboBoxWidget</name>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="238"/>
        <source>False</source>
        <translation>Ложь</translation>
    </message>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="239"/>
        <source>True</source>
        <translation>Истина</translation>
    </message>
</context>
<context>
    <name>U2::ComboBoxWithUrlWidget</name>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="364"/>
        <source>Select a folder</source>
        <translation>Укажите папку</translation>
    </message>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="369"/>
        <source>Select a file</source>
        <translation>Выберите файл</translation>
    </message>
</context>
<context>
    <name>U2::CreateDirectoryDialog</name>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="210"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="211"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::Dashboard</name>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="145"/>
        <source>Overview</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="154"/>
        <source>Input</source>
        <translation>Входные данные</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="162"/>
        <location filename="../src/dashboard/Dashboard.cpp" line="236"/>
        <source>External Tools</source>
        <translation>Внешние инструменты</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="181"/>
        <source>Open workflow schema</source>
        <translation>Открыть схему</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="200"/>
        <source>Output files</source>
        <translation>Выходные файлы</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="204"/>
        <source>Workflow task</source>
        <translation>Задача</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="208"/>
        <source>Notifications</source>
        <translation>Нотификации</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="213"/>
        <source>Common statistics</source>
        <translation>Общая статистика</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="221"/>
        <source>Parameters</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="326"/>
        <source>Can not create a folder: </source>
        <translation>Невозможно создать папку: </translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="332"/>
        <source>Failed to open Dashboard.html</source>
        <translation>Невозможно открыть Dashboard.html</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="483"/>
        <source>Error reading dashboard file: %1</source>
        <translation>Ошибка чтения файла: %1</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="495"/>
        <source>Error parsing dashboard file: &apos;%1&apos;, file: %2</source>
        <translation>Ошибка парсинга файла: &apos;%1&apos;, файл: %2</translation>
    </message>
</context>
<context>
    <name>U2::DashboardFileButton</name>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="217"/>
        <source>%1 file(s)</source>
        <translation>%1 файл(ов)</translation>
    </message>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="268"/>
        <source>Open file with UGENE</source>
        <translation>Открыть в UGENE</translation>
    </message>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="274"/>
        <source>Open folder with the file</source>
        <translation>Открыть папку содержащую файл</translation>
    </message>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="279"/>
        <source>Open file by OS</source>
        <translation>Открыть файл при помощи операционной системы</translation>
    </message>
</context>
<context>
    <name>U2::DashboardInfoRegistry</name>
    <message>
        <location filename="../src/dashboard/DashboardInfoRegistry.cpp" line="139"/>
        <source>Can&apos;t register a dashboard info: &apos;%1&apos;</source>
        <translation>Не удается зарегистрировать информацию: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>U2::DashboardWidget</name>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="337"/>
        <source>File is not found: %1</source>
        <translation>Файл не найден: %1</translation>
    </message>
</context>
<context>
    <name>U2::DatasetsController</name>
    <message>
        <location filename="../src/DatasetsController.cpp" line="166"/>
        <source>Dataset name is empty</source>
        <translation>Имя набора данных пустое</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="170"/>
        <source>Dataset name can not contain &apos;:&apos; and &apos;;&apos; symbols</source>
        <translation>Имя набора данных не может содержать &apos;:&apos; и &apos;;&apos; символы</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="175"/>
        <source>This dataset name already exists</source>
        <translation>Это имя набора данных уже существует</translation>
    </message>
</context>
<context>
    <name>U2::DatasetsListWidget</name>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="54"/>
        <source>Add dataset</source>
        <translation>Добавить набор данных</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="98"/>
        <source>Enter Dataset Name</source>
        <translation>Ввести имя набора данных</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="99"/>
        <location filename="../src/DatasetsListWidget.cpp" line="132"/>
        <source>New dataset name:</source>
        <translation>Имя нового набора данных:</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="110"/>
        <location filename="../src/DatasetsListWidget.cpp" line="142"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="131"/>
        <source>Rename Dataset</source>
        <translation>Переименовать набор данных</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="152"/>
        <source>Rename dataset</source>
        <translation>Переименовать набор данных</translation>
    </message>
</context>
<context>
    <name>U2::DbFolderItem</name>
    <message>
        <location filename="../src/DbFolderItem.cpp" line="41"/>
        <source>Use &lt;i&gt;right click&lt;/i&gt; to set advanced options</source>
        <translation>Используйте &lt;i&gt;правый клик мыши&lt;/i&gt; чтобы установить дополнительные опции</translation>
    </message>
</context>
<context>
    <name>U2::DbObjectItem</name>
    <message>
        <location filename="../src/DbObjectItem.cpp" line="37"/>
        <source>&quot; is located in the database &lt;b&gt;</source>
        <translation>&quot; расположено в наборе данных &lt;b&gt;</translation>
    </message>
</context>
<context>
    <name>U2::DirectoryItem</name>
    <message>
        <location filename="../src/DirectoryItem.cpp" line="36"/>
        <source>Use &lt;i&gt;right click&lt;/i&gt; to set advanced options</source>
        <translation>Используйте &lt;i&gt;правый клик мыши&lt;/i&gt; чтобы установить дополнительные опции</translation>
    </message>
</context>
<context>
    <name>U2::EditBreakpointLabelsDialog</name>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.cpp" line="48"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::EditMarkerDialog</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="403"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="404"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="412"/>
        <source>Create Marker</source>
        <translation>Создание маркера</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="451"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="456"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>U2::EditMarkerGroupDialog</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="47"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="48"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="87"/>
        <source>Create Marker Group</source>
        <translation>Создание группы маркеров</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="190"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="291"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="298"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="303"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="190"/>
        <source>You can not remove the required marker &quot;rest&quot;</source>
        <translation>Вы не можете удалить выбранный маркер &quot;rest&quot;</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="210"/>
        <source>Warning</source>
        <translation>Ожидание</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="211"/>
        <source>Are you really want to change marker&apos;s type? Some data can be lost!</source>
        <translation>Вы действиетльно хотите изменить тип маркера? Некоторые данные могут быть утеряны!</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="240"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="264"/>
        <source>Marker&apos;s name contains a comma symbol: &quot;%1&quot;. It is not permitted for marker names</source>
        <translation>Имя маркера содержит запрещенный символ: &quot;%1&quot;. Это недопустимо для имени маркера</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="246"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="269"/>
        <source>Duplicate marker&apos;s value: %1</source>
        <translation>Повторяющееся значение маркера: %1</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="253"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="274"/>
        <source>Duplicate marker&apos;s name: %1</source>
        <translation>Повторящееся имя маркера: %1</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="291"/>
        <source>Parameter &apos;%1&apos; is not set</source>
        <translation>Параметр &apos;%1&apos; не установлен</translation>
    </message>
</context>
<context>
    <name>U2::GroupBox</name>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="910"/>
        <source>Show</source>
        <translation>Показать</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="915"/>
        <source>Hide</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="935"/>
        <source>additional</source>
        <translation>дополнительно</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="939"/>
        <source> settings</source>
        <translation> настройки</translation>
    </message>
</context>
<context>
    <name>U2::GrouperEditorWidget</name>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="75"/>
        <source>&lt;Unset&gt;</source>
        <translation>&lt;Unset&gt;</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="111"/>
        <source>By value</source>
        <translation>По значению</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="117"/>
        <source>By id</source>
        <translation>По идентификатору</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="118"/>
        <source>By name</source>
        <translation>По имени</translation>
    </message>
</context>
<context>
    <name>U2::GrouperSlotsCfgModel</name>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="300"/>
        <source>Output slot name</source>
        <translation>Имя выходного слота</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="302"/>
        <source>Source data slot</source>
        <translation>Слот источника данных</translation>
    </message>
</context>
<context>
    <name>U2::MarkerEditorWidget</name>
    <message>
        <location filename="../src/MarkerEditorWidget.cpp" line="127"/>
        <location filename="../src/MarkerEditorWidget.cpp" line="143"/>
        <source>Duplicate marker&apos;s name: %1</source>
        <translation>Повторящееся имя маркера: %1</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.cpp" line="150"/>
        <source>Marker&apos;s name contains spaces: %1</source>
        <translation>Имя маркера содержит пробелы: %1</translation>
    </message>
</context>
<context>
    <name>U2::MarkerListCfgModel</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="350"/>
        <source>Marker name</source>
        <translation>Имя маркера</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="352"/>
        <source>Marker value</source>
        <translation>Значение маркера</translation>
    </message>
</context>
<context>
    <name>U2::MsaActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="216"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="217"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::NewBreakpointDialog</name>
    <message>
        <location filename="../src/NewBreakpointDialog.cpp" line="36"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/NewBreakpointDialog.cpp" line="37"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::NewGrouperSlotDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="39"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="40"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="53"/>
        <source>Empty output slot name.</source>
        <translation>Имя выходного слота пусто.</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="55"/>
        <source>Invalid symbols in the output slot name. Use letters and digits only.</source>
        <translation>Запрещенные символы в имени выходного слота. Используйте только буквы и цифры.</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="57"/>
        <source>This output out slot already exists.</source>
        <translation>Такой выходной слот уже существует.</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="63"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>U2::NotificationsDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="68"/>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="127"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="68"/>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="127"/>
        <source>Element</source>
        <translation>Элемент</translation>
    </message>
    <message>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="68"/>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="127"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
</context>
<context>
    <name>U2::OutputDirectoryWidget</name>
    <message>
        <location filename="../src/support/OutputDirectoryWidget.cpp" line="43"/>
        <source>The Workflow Output Folder is a common folder that is used to store all output files in the Workflow Designer. A separate subdirectory of the folder is created for each run of a workflow.

Set up the folder:</source>
        <translation>Выходная директория для схемы это общая директория, которая используется для сохранения всех выходных файлов в дизайнере вычислительных схем. Для каждого запуска схемы будет создана отдельная директория.

Установить директорию:</translation>
    </message>
    <message>
        <location filename="../src/support/OutputDirectoryWidget.cpp" line="68"/>
        <source>Select a folder</source>
        <translation>Укажите папку</translation>
    </message>
</context>
<context>
    <name>U2::OutputFileDialog</name>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="50"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="55"/>
        <source>Save a folder</source>
        <translation>Сохранить папку</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="57"/>
        <source>Save a file</source>
        <translation>Сохранить файл</translation>
    </message>
</context>
<context>
    <name>U2::OutputFilesDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="76"/>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="151"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="76"/>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="151"/>
        <source>Producer</source>
        <translation>Производитель</translation>
    </message>
</context>
<context>
    <name>U2::ParametersDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="224"/>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="290"/>
        <source>Parameter</source>
        <translation>Параметр</translation>
    </message>
    <message>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="224"/>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="290"/>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
</context>
<context>
    <name>U2::QDCreateAnnotationsTask</name>
    <message>
        <location filename="../src/QDScheduler.h" line="195"/>
        <source>Prepare annotations task</source>
        <translation>Подготовка задачи аннотирования</translation>
    </message>
</context>
<context>
    <name>U2::QDFindLocationTask</name>
    <message>
        <location filename="../src/QDScheduler.h" line="137"/>
        <source>Find resultLocation</source>
        <translation>Поиск расположения результата</translation>
    </message>
</context>
<context>
    <name>U2::QDLinkResultsTask</name>
    <message>
        <location filename="../src/QDScheduler.h" line="162"/>
        <source>Link results</source>
        <translation>Ссылка на результаты</translation>
    </message>
</context>
<context>
    <name>U2::QDScheduler</name>
    <message>
        <location filename="../src/QDScheduler.cpp" line="47"/>
        <source>QDScheduler</source>
        <translation>QDScheduler</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="77"/>
        <source>Can&apos;t find annotation object: %1 in document: %2</source>
        <translation>Невозможно найти объект аннотация: %1 в документе: %2</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="110"/>
        <source>Annotation object is not available</source>
        <translation>Объект аннотация недоступен</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="369"/>
        <source>No results have been found for this scheme</source>
        <translation>Для этой схемы результатов не найдено</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="486"/>
        <source>Too many results have been found for this scheme. Try to set stricter search conditions.</source>
        <translation>Было найдено очень много результатов для этой схемы. Попробуйте изменить условия поиска.</translation>
    </message>
</context>
<context>
    <name>U2::QDTask</name>
    <message>
        <location filename="../src/QDScheduler.cpp" line="760"/>
        <source>Query task: %1</source>
        <translation>Запрос: %1</translation>
    </message>
</context>
<context>
    <name>U2::RemoveDashboardsTask</name>
    <message>
        <location filename="../src/dashboard/RemoveDashboardsTask.cpp" line="30"/>
        <source>Remove dashboards</source>
        <translation>Удалить панель</translation>
    </message>
</context>
<context>
    <name>U2::ScanDashboardsDirTask</name>
    <message>
        <location filename="../src/dashboard/ScanDashboardsDirTask.cpp" line="36"/>
        <source>Scan dashboards folder</source>
        <translation>Сканирование папки панели</translation>
    </message>
</context>
<context>
    <name>U2::SchemaRunModeDelegate</name>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="600"/>
        <source>This computer</source>
        <translation>Данный компьютер</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="601"/>
        <source>Remote computer</source>
        <translation>Удаленный компьютер</translation>
    </message>
</context>
<context>
    <name>U2::SequeceActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="152"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="153"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::StatisticsDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="64"/>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="77"/>
        <source>Element</source>
        <translation>Элемент</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="64"/>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="77"/>
        <source>Elapsed time</source>
        <translation>Время выполнения</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="64"/>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="77"/>
        <source>Output messages</source>
        <translation>Выходные сообщения</translation>
    </message>
</context>
<context>
    <name>U2::StatusDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="80"/>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="147"/>
        <source>Time %1</source>
        <translation>Время %1</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="157"/>
        <source>The workflow task is in progress…</source>
        <translation>Задача в процессе выполнения...</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="159"/>
        <source>The workflow task is in progress. There are problems…</source>
        <translation>Задача в процессе выполнения. Возникли следующие проблемы...</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="161"/>
        <source>The workflow task has been finished with warnings!</source>
        <translation>Задача закончилась с предупреждениями!</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="163"/>
        <source>The workflow task has been finished with errors!</source>
        <translation>Задача закончилась с ошибками!</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="165"/>
        <source>The workflow task has been finished successfully!</source>
        <translation>Задача закончилась без ошибок!</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="167"/>
        <source>The workflow task has been canceled!</source>
        <translation>Задача была отменена!</translation>
    </message>
</context>
<context>
    <name>U2::StringActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="249"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="250"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::StringListDelegate</name>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="726"/>
        <source>Enter items</source>
        <translation>Введите элементы</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="728"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="730"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::TophatSamples</name>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="280"/>
        <source>Divide the input datasets into samples for running Cuffdiff. There are must be at least 2 samples. It is not necessary to have the same number of datasets (replicates) for each sample. The samples names will be used by Cuffdiff as labels, which will be included in various output files produced by Cuffdiff.</source>
        <translation>Разделите входные наборы данных на образцы для запуска Cuffdiff. Должно быть не менее двух образцов. Необязательно иметь одинаковое число наборов данных для каждого образца. Имена образцов будут использоваться Cuffdiff в качестве меток, которые будут включены в различные выходные Cuffdiff файлы.</translation>
    </message>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="358"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>U2::TophatSamplesWidgetController</name>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="59"/>
        <source>Sample name can not be empty</source>
        <translation>Имя образца не может быть пустым</translation>
    </message>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="64"/>
        <source>Sample name can consist only of Latin letters, numbers and the &apos;_&apos; symbol</source>
        <translation>Имя образца может состоять только из латинских букв, цифр и &apos;_&apos; символов</translation>
    </message>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="72"/>
        <source>Duplicate sample name</source>
        <translation>Повторяющееся имя образца</translation>
    </message>
</context>
<context>
    <name>U2::URLLineEdit</name>
    <message>
        <location filename="../src/support/URLLineEdit.cpp" line="182"/>
        <source>Select a folder</source>
        <translation>Укажите папку</translation>
    </message>
    <message>
        <location filename="../src/support/URLLineEdit.cpp" line="200"/>
        <location filename="../src/support/URLLineEdit.cpp" line="203"/>
        <source>Select a file</source>
        <translation>Выберите файл</translation>
    </message>
    <message>
        <location filename="../src/support/URLLineEdit.cpp" line="185"/>
        <source>Select file(s)</source>
        <translation>Выберите файл(ы)</translation>
    </message>
</context>
<context>
    <name>U2::URLListController</name>
    <message>
        <location filename="../src/DatasetsController.cpp" line="756"/>
        <source>This file or folder does not exist: %1</source>
        <translation>Этот файл или папка не существует: %1</translation>
    </message>
</context>
<context>
    <name>U2::URLListWidget</name>
    <message>
        <location filename="../src/DatasetWidget.cpp" line="108"/>
        <location filename="../src/DatasetWidget.cpp" line="110"/>
        <source>Select file</source>
        <translation>Выберите файл</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.cpp" line="120"/>
        <source>Select a folder</source>
        <translation>Укажите папку</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.cpp" line="131"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>U2::URLWidget</name>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="505"/>
        <source>add</source>
        <translation>добавить</translation>
    </message>
</context>
<context>
    <name>U2::WizardController</name>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="100"/>
        <source>Apply</source>
        <translation>Принять</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="122"/>
        <source>Defaults</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="123"/>
        <source>Set page values by default</source>
        <translation>Установить значения по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="128"/>
        <source>Run</source>
        <translation>Запустить</translation>
    </message>
</context>
<context>
    <name>U2::Workflow::MarkerGroupListCfgModel</name>
    <message>
        <location filename="../src/MarkerEditor.cpp" line="180"/>
        <source>Marker Group</source>
        <translation>Группа маркера</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditor.cpp" line="182"/>
        <source>Marker Value</source>
        <translation>Значение маркера</translation>
    </message>
</context>
<context>
    <name>U2::WorkflowUtils</name>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="588"/>
        <source>Overwrite</source>
        <translation>Переписать</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="589"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="591"/>
        <source>Append</source>
        <translation>Дописать</translation>
    </message>
    <message>
        <location filename="../src/DesignerUtils.cpp" line="33"/>
        <source>UGENE workflow documents</source>
        <translation>Вычислительные схемы UGENE</translation>
    </message>
</context>
</TS>
